package com.google.android.gms.common.api.internal;

import android.os.Looper;
import android.support.annotation.NonNull;
import android.util.Log;
import com.google.android.gms.common.api.GoogleApiClient;
import com.google.android.gms.common.api.PendingResult;
import com.google.android.gms.common.api.Releasable;
import com.google.android.gms.common.api.Result;
import com.google.android.gms.common.api.ResultCallback;
import com.google.android.gms.common.api.ResultCallbacks;
import com.google.android.gms.common.api.ResultTransform;
import com.google.android.gms.common.api.Status;
import com.google.android.gms.common.api.TransformedResult;
import com.google.android.gms.common.internal.zzbq;
import java.lang.ref.WeakReference;
import java.util.concurrent.ExecutorService;

public final class zzdh<R extends Result>
  extends TransformedResult<R>
  implements ResultCallback<R>
{
  private ResultTransform<? super R, ? extends Result> zzgbh = null;
  private zzdh<? extends Result> zzgbi = null;
  private volatile ResultCallbacks<? super R> zzgbj = null;
  private PendingResult<R> zzgbk = null;
  private final Object zzfvc = new Object();
  private Status zzgbl = null;
  private final WeakReference<GoogleApiClient> zzfve;
  private final zzdj zzgbm;
  private boolean zzgbn = false;
  
  public zzdh(WeakReference<GoogleApiClient> paramWeakReference)
  {
    zzbq.checkNotNull(paramWeakReference, "GoogleApiClient reference must not be null");
    this.zzfve = paramWeakReference;
    GoogleApiClient localGoogleApiClient = (GoogleApiClient)this.zzfve.get();
    this.zzgbm = new zzdj(this, localGoogleApiClient != null ? localGoogleApiClient.getLooper() : Looper.getMainLooper());
  }
  
  @NonNull
  public final <S extends Result> TransformedResult<S> then(@NonNull ResultTransform<? super R, ? extends S> paramResultTransform)
  {
    synchronized (this.zzfvc)
    {
      zzbq.zza(this.zzgbh == null, "Cannot call then() twice.");
      zzbq.zza(this.zzgbj == null, "Cannot call then() and andFinally() on the same TransformedResult.");
      this.zzgbh = paramResultTransform;
      zzdh localzzdh = new zzdh(this.zzfve);
      this.zzgbi = localzzdh;
      zzala();
      return localzzdh;
    }
  }
  
  public final void andFinally(@NonNull ResultCallbacks<? super R> paramResultCallbacks)
  {
    synchronized (this.zzfvc)
    {
      zzbq.zza(this.zzgbj == null, "Cannot call andFinally() twice.");
      zzbq.zza(this.zzgbh == null, "Cannot call then() and andFinally() on the same TransformedResult.");
      this.zzgbj = paramResultCallbacks;
      zzala();
      return;
    }
  }
  
  public final void onResult(R paramR)
  {
    synchronized (this.zzfvc)
    {
      if (paramR.getStatus().isSuccess())
      {
        if (this.zzgbh != null) {
          zzcs.zzajx().submit(new zzdi(this, paramR));
        } else if (zzalc()) {
          this.zzgbj.onSuccess(paramR);
        }
      }
      else
      {
        zzd(paramR.getStatus());
        zzd(paramR);
      }
      return;
    }
  }
  
  public final void zza(PendingResult<?> paramPendingResult)
  {
    synchronized (this.zzfvc)
    {
      this.zzgbk = paramPendingResult;
      zzala();
      return;
    }
  }
  
  private final void zzala()
  {
    if ((this.zzgbh == null) && (this.zzgbj == null)) {
      return;
    }
    GoogleApiClient localGoogleApiClient = (GoogleApiClient)this.zzfve.get();
    if ((!this.zzgbn) && (this.zzgbh != null) && (localGoogleApiClient != null))
    {
      localGoogleApiClient.zza(this);
      this.zzgbn = true;
    }
    if (this.zzgbl != null)
    {
      zzx(this.zzgbl);
      return;
    }
    if (this.zzgbk != null) {
      this.zzgbk.setResultCallback(this);
    }
  }
  
  private final void zzd(Status paramStatus)
  {
    synchronized (this.zzfvc)
    {
      this.zzgbl = paramStatus;
      zzx(this.zzgbl);
      return;
    }
  }
  
  private final void zzx(Status paramStatus)
  {
    synchronized (this.zzfvc)
    {
      if (this.zzgbh != null)
      {
        Status localStatus;
        zzbq.checkNotNull(localStatus = this.zzgbh.onFailure(paramStatus), "onFailure must not return null");
        this.zzgbi.zzd(localStatus);
      }
      else if (zzalc())
      {
        this.zzgbj.onFailure(paramStatus);
      }
      return;
    }
  }
  
  final void zzalb()
  {
    this.zzgbj = null;
  }
  
  private final boolean zzalc()
  {
    GoogleApiClient localGoogleApiClient = (GoogleApiClient)this.zzfve.get();
    return (this.zzgbj != null) && (localGoogleApiClient != null);
  }
  
  private static void zzd(Result paramResult)
  {
    if ((paramResult instanceof Releasable)) {
      try
      {
        ((Releasable)paramResult).release();
        return;
      }
      catch (RuntimeException localRuntimeException)
      {
        String str = String.valueOf(paramResult);
        Log.w("TransformedResultImpl", 18 + String.valueOf(str).length() + "Unable to release " + str, localRuntimeException);
      }
    }
  }
}


/* Location:              C:\Users\nsubhash\Downloads\google-play-services-base.jar!\com\google\android\gms\common\api\internal\zzdh.class
 * Java compiler version: 7 (51.0)
 * JD-Core Version:       0.7.1
 */